from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Phone.PersonalInformation
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class ContactAddress(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Phone.PersonalInformation.IContactAddress
    _classid_ = 'Windows.Phone.PersonalInformation.ContactAddress'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Phone.PersonalInformation.ContactAddress.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Phone.PersonalInformation.ContactAddress: ...
    @winrt_mixinmethod
    def get_Country(self: win32more.Windows.Phone.PersonalInformation.IContactAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Country(self: win32more.Windows.Phone.PersonalInformation.IContactAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Locality(self: win32more.Windows.Phone.PersonalInformation.IContactAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Locality(self: win32more.Windows.Phone.PersonalInformation.IContactAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Region(self: win32more.Windows.Phone.PersonalInformation.IContactAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Region(self: win32more.Windows.Phone.PersonalInformation.IContactAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_PostalCode(self: win32more.Windows.Phone.PersonalInformation.IContactAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PostalCode(self: win32more.Windows.Phone.PersonalInformation.IContactAddress, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_StreetAddress(self: win32more.Windows.Phone.PersonalInformation.IContactAddress) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_StreetAddress(self: win32more.Windows.Phone.PersonalInformation.IContactAddress, value: WinRT_String) -> Void: ...
    Country = property(get_Country, put_Country)
    Locality = property(get_Locality, put_Locality)
    PostalCode = property(get_PostalCode, put_PostalCode)
    Region = property(get_Region, put_Region)
    StreetAddress = property(get_StreetAddress, put_StreetAddress)
class ContactChangeRecord(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Phone.PersonalInformation.IContactChangeRecord
    _classid_ = 'Windows.Phone.PersonalInformation.ContactChangeRecord'
    @winrt_mixinmethod
    def get_ChangeType(self: win32more.Windows.Phone.PersonalInformation.IContactChangeRecord) -> win32more.Windows.Phone.PersonalInformation.ContactChangeType: ...
    @winrt_mixinmethod
    def get_RevisionNumber(self: win32more.Windows.Phone.PersonalInformation.IContactChangeRecord) -> UInt64: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Phone.PersonalInformation.IContactChangeRecord) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_RemoteId(self: win32more.Windows.Phone.PersonalInformation.IContactChangeRecord) -> WinRT_String: ...
    ChangeType = property(get_ChangeType, None)
    Id = property(get_Id, None)
    RemoteId = property(get_RemoteId, None)
    RevisionNumber = property(get_RevisionNumber, None)
class ContactChangeType(Enum, Int32):
    Created = 0
    Modified = 1
    Deleted = 2
class ContactInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Phone.PersonalInformation.IContactInformation
    _classid_ = 'Windows.Phone.PersonalInformation.ContactInformation'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Phone.PersonalInformation.ContactInformation.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Phone.PersonalInformation.ContactInformation: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_FamilyName(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_FamilyName(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_GivenName(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_GivenName(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_HonorificPrefix(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_HonorificPrefix(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_HonorificSuffix(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_HonorificSuffix(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def GetDisplayPictureAsync(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_mixinmethod
    def SetDisplayPictureAsync(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, stream: win32more.Windows.Storage.Streams.IInputStream) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def get_DisplayPicture(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def GetPropertiesAsync(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]: ...
    @winrt_mixinmethod
    def ToVcardAsync(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_mixinmethod
    def ToVcardWithOptionsAsync(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, format: win32more.Windows.Phone.PersonalInformation.VCardFormat) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_classmethod
    def ParseVcardAsync(cls: win32more.Windows.Phone.PersonalInformation.IContactInformationStatics, vcard: win32more.Windows.Storage.Streams.IInputStream) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Phone.PersonalInformation.ContactInformation]: ...
    DisplayName = property(get_DisplayName, put_DisplayName)
    DisplayPicture = property(get_DisplayPicture, None)
    FamilyName = property(get_FamilyName, put_FamilyName)
    GivenName = property(get_GivenName, put_GivenName)
    HonorificPrefix = property(get_HonorificPrefix, put_HonorificPrefix)
    HonorificSuffix = property(get_HonorificSuffix, put_HonorificSuffix)
class ContactQueryOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Phone.PersonalInformation.IContactQueryOptions
    _classid_ = 'Windows.Phone.PersonalInformation.ContactQueryOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Phone.PersonalInformation.ContactQueryOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Phone.PersonalInformation.ContactQueryOptions: ...
    @winrt_mixinmethod
    def get_DesiredFields(self: win32more.Windows.Phone.PersonalInformation.IContactQueryOptions) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_mixinmethod
    def get_OrderBy(self: win32more.Windows.Phone.PersonalInformation.IContactQueryOptions) -> win32more.Windows.Phone.PersonalInformation.ContactQueryResultOrdering: ...
    @winrt_mixinmethod
    def put_OrderBy(self: win32more.Windows.Phone.PersonalInformation.IContactQueryOptions, value: win32more.Windows.Phone.PersonalInformation.ContactQueryResultOrdering) -> Void: ...
    DesiredFields = property(get_DesiredFields, None)
    OrderBy = property(get_OrderBy, put_OrderBy)
class ContactQueryResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Phone.PersonalInformation.IContactQueryResult
    _classid_ = 'Windows.Phone.PersonalInformation.ContactQueryResult'
    @winrt_mixinmethod
    def GetContactCountAsync(self: win32more.Windows.Phone.PersonalInformation.IContactQueryResult) -> win32more.Windows.Foundation.IAsyncOperation[UInt32]: ...
    @winrt_mixinmethod
    def GetContactsAsync(self: win32more.Windows.Phone.PersonalInformation.IContactQueryResult) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Phone.PersonalInformation.StoredContact]]: ...
    @winrt_mixinmethod
    def GetContactsAsyncInRange(self: win32more.Windows.Phone.PersonalInformation.IContactQueryResult, startIndex: UInt32, maxNumberOfItems: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Phone.PersonalInformation.StoredContact]]: ...
    @winrt_mixinmethod
    def GetCurrentQueryOptions(self: win32more.Windows.Phone.PersonalInformation.IContactQueryResult) -> win32more.Windows.Phone.PersonalInformation.ContactQueryOptions: ...
class ContactQueryResultOrdering(Enum, Int32):
    SystemDefault = 0
    GivenNameFamilyName = 1
    FamilyNameGivenName = 2
class ContactStore(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Phone.PersonalInformation.IContactStore
    _classid_ = 'Windows.Phone.PersonalInformation.ContactStore'
    @winrt_mixinmethod
    def FindContactByRemoteIdAsync(self: win32more.Windows.Phone.PersonalInformation.IContactStore, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Phone.PersonalInformation.StoredContact]: ...
    @winrt_mixinmethod
    def FindContactByIdAsync(self: win32more.Windows.Phone.PersonalInformation.IContactStore, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Phone.PersonalInformation.StoredContact]: ...
    @winrt_mixinmethod
    def DeleteContactAsync(self: win32more.Windows.Phone.PersonalInformation.IContactStore, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def CreateContactQueryDefault(self: win32more.Windows.Phone.PersonalInformation.IContactStore) -> win32more.Windows.Phone.PersonalInformation.ContactQueryResult: ...
    @winrt_mixinmethod
    def CreateContactQueryWithOptions(self: win32more.Windows.Phone.PersonalInformation.IContactStore, options: win32more.Windows.Phone.PersonalInformation.ContactQueryOptions) -> win32more.Windows.Phone.PersonalInformation.ContactQueryResult: ...
    @winrt_mixinmethod
    def DeleteAsync(self: win32more.Windows.Phone.PersonalInformation.IContactStore) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def get_RevisionNumber(self: win32more.Windows.Phone.PersonalInformation.IContactStore) -> UInt64: ...
    @winrt_mixinmethod
    def GetChangesAsync(self: win32more.Windows.Phone.PersonalInformation.IContactStore, baseRevisionNumber: UInt64) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Phone.PersonalInformation.ContactChangeRecord]]: ...
    @winrt_mixinmethod
    def LoadExtendedPropertiesAsync(self: win32more.Windows.Phone.PersonalInformation.IContactStore) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]: ...
    @winrt_mixinmethod
    def SaveExtendedPropertiesAsync(self: win32more.Windows.Phone.PersonalInformation.IContactStore, data: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def CreateMeContactAsync(self: win32more.Windows.Phone.PersonalInformation.IContactStore2, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Phone.PersonalInformation.StoredContact]: ...
    @winrt_classmethod
    def CreateOrOpenAsync(cls: win32more.Windows.Phone.PersonalInformation.IContactStoreStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Phone.PersonalInformation.ContactStore]: ...
    @winrt_classmethod
    def CreateOrOpenWithOptionsAsync(cls: win32more.Windows.Phone.PersonalInformation.IContactStoreStatics, access: win32more.Windows.Phone.PersonalInformation.ContactStoreSystemAccessMode, sharing: win32more.Windows.Phone.PersonalInformation.ContactStoreApplicationAccessMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Phone.PersonalInformation.ContactStore]: ...
    RevisionNumber = property(get_RevisionNumber, None)
class ContactStoreApplicationAccessMode(Enum, Int32):
    LimitedReadOnly = 0
    ReadOnly = 1
class ContactStoreSystemAccessMode(Enum, Int32):
    ReadOnly = 0
    ReadWrite = 1
class IContactAddress(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.IContactAddress'
    _iid_ = Guid('{5f24f927-94a9-44a2-a155-2d0b37d1dccd}')
    @winrt_commethod(6)
    def get_Country(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Country(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Locality(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_Locality(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_Region(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_Region(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_PostalCode(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_PostalCode(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_StreetAddress(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def put_StreetAddress(self, value: WinRT_String) -> Void: ...
    Country = property(get_Country, put_Country)
    Locality = property(get_Locality, put_Locality)
    PostalCode = property(get_PostalCode, put_PostalCode)
    Region = property(get_Region, put_Region)
    StreetAddress = property(get_StreetAddress, put_StreetAddress)
class IContactChangeRecord(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.IContactChangeRecord'
    _iid_ = Guid('{b9d3f78f-513b-4742-be00-cc5c5c236b04}')
    @winrt_commethod(6)
    def get_ChangeType(self) -> win32more.Windows.Phone.PersonalInformation.ContactChangeType: ...
    @winrt_commethod(7)
    def get_RevisionNumber(self) -> UInt64: ...
    @winrt_commethod(8)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_RemoteId(self) -> WinRT_String: ...
    ChangeType = property(get_ChangeType, None)
    Id = property(get_Id, None)
    RemoteId = property(get_RemoteId, None)
    RevisionNumber = property(get_RevisionNumber, None)
class IContactInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.IContactInformation'
    _iid_ = Guid('{e2b51ffc-e792-4ab7-b15b-f2e078664dea}')
    @winrt_commethod(6)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_DisplayName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_FamilyName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_FamilyName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_GivenName(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def put_GivenName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def get_HonorificPrefix(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_HonorificPrefix(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_HonorificSuffix(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def put_HonorificSuffix(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(16)
    def GetDisplayPictureAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_commethod(17)
    def SetDisplayPictureAsync(self, stream: win32more.Windows.Storage.Streams.IInputStream) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(18)
    def get_DisplayPicture(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(19)
    def GetPropertiesAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]: ...
    @winrt_commethod(20)
    def ToVcardAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_commethod(21)
    def ToVcardWithOptionsAsync(self, format: win32more.Windows.Phone.PersonalInformation.VCardFormat) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    DisplayName = property(get_DisplayName, put_DisplayName)
    DisplayPicture = property(get_DisplayPicture, None)
    FamilyName = property(get_FamilyName, put_FamilyName)
    GivenName = property(get_GivenName, put_GivenName)
    HonorificPrefix = property(get_HonorificPrefix, put_HonorificPrefix)
    HonorificSuffix = property(get_HonorificSuffix, put_HonorificSuffix)
class IContactInformation2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.IContactInformation2'
    _iid_ = Guid('{3198b20c-621e-4668-ac38-d667b87d06d5}')
    @winrt_commethod(6)
    def get_DisplayPictureDate(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(7)
    def put_DisplayPictureDate(self, returnValue: win32more.Windows.Foundation.DateTime) -> Void: ...
    DisplayPictureDate = property(get_DisplayPictureDate, put_DisplayPictureDate)
class IContactInformationStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.IContactInformationStatics'
    _iid_ = Guid('{0f67bb29-03d0-4be6-b2a5-fb13859f1202}')
    @winrt_commethod(6)
    def ParseVcardAsync(self, vcard: win32more.Windows.Storage.Streams.IInputStream) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Phone.PersonalInformation.ContactInformation]: ...
class IContactQueryOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.IContactQueryOptions'
    _iid_ = Guid('{580cab76-3f31-46c1-9a50-424a53dacae3}')
    @winrt_commethod(6)
    def get_DesiredFields(self) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    @winrt_commethod(7)
    def get_OrderBy(self) -> win32more.Windows.Phone.PersonalInformation.ContactQueryResultOrdering: ...
    @winrt_commethod(8)
    def put_OrderBy(self, value: win32more.Windows.Phone.PersonalInformation.ContactQueryResultOrdering) -> Void: ...
    DesiredFields = property(get_DesiredFields, None)
    OrderBy = property(get_OrderBy, put_OrderBy)
class IContactQueryResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.IContactQueryResult'
    _iid_ = Guid('{c03db722-ecdb-4700-857e-3e786426b04b}')
    @winrt_commethod(6)
    def GetContactCountAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[UInt32]: ...
    @winrt_commethod(7)
    def GetContactsAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Phone.PersonalInformation.StoredContact]]: ...
    @winrt_commethod(8)
    def GetContactsAsyncInRange(self, startIndex: UInt32, maxNumberOfItems: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Phone.PersonalInformation.StoredContact]]: ...
    @winrt_commethod(9)
    def GetCurrentQueryOptions(self) -> win32more.Windows.Phone.PersonalInformation.ContactQueryOptions: ...
class IContactStore(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.IContactStore'
    _iid_ = Guid('{b2cd6fef-2bfd-4fad-8552-4e698097e8eb}')
    @winrt_commethod(6)
    def FindContactByRemoteIdAsync(self, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Phone.PersonalInformation.StoredContact]: ...
    @winrt_commethod(7)
    def FindContactByIdAsync(self, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Phone.PersonalInformation.StoredContact]: ...
    @winrt_commethod(8)
    def DeleteContactAsync(self, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def CreateContactQueryDefault(self) -> win32more.Windows.Phone.PersonalInformation.ContactQueryResult: ...
    @winrt_commethod(10)
    def CreateContactQueryWithOptions(self, options: win32more.Windows.Phone.PersonalInformation.ContactQueryOptions) -> win32more.Windows.Phone.PersonalInformation.ContactQueryResult: ...
    @winrt_commethod(11)
    def DeleteAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(12)
    def get_RevisionNumber(self) -> UInt64: ...
    @winrt_commethod(13)
    def GetChangesAsync(self, baseRevisionNumber: UInt64) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Phone.PersonalInformation.ContactChangeRecord]]: ...
    @winrt_commethod(14)
    def LoadExtendedPropertiesAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]: ...
    @winrt_commethod(15)
    def SaveExtendedPropertiesAsync(self, data: win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.IAsyncAction: ...
    RevisionNumber = property(get_RevisionNumber, None)
class IContactStore2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.IContactStore2'
    _iid_ = Guid('{65f1b64f-d653-43a7-b236-b30c0f4d7269}')
    @winrt_commethod(6)
    def CreateMeContactAsync(self, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Phone.PersonalInformation.StoredContact]: ...
class IContactStoreStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.IContactStoreStatics'
    _iid_ = Guid('{a804fe22-4beb-44cc-a572-67a5b92e8567}')
    @winrt_commethod(6)
    def CreateOrOpenAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Phone.PersonalInformation.ContactStore]: ...
    @winrt_commethod(7)
    def CreateOrOpenWithOptionsAsync(self, access: win32more.Windows.Phone.PersonalInformation.ContactStoreSystemAccessMode, sharing: win32more.Windows.Phone.PersonalInformation.ContactStoreApplicationAccessMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Phone.PersonalInformation.ContactStore]: ...
class IKnownContactPropertiesStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics'
    _iid_ = Guid('{d5812b01-2ced-4ee6-b1d6-094bf88ef0b6}')
    @winrt_commethod(6)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_FamilyName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_GivenName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_HonorificPrefix(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_HonorificSuffix(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def get_AdditionalName(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def get_Address(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def get_OtherAddress(self) -> WinRT_String: ...
    @winrt_commethod(14)
    def get_Email(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def get_WorkAddress(self) -> WinRT_String: ...
    @winrt_commethod(16)
    def get_WorkTelephone(self) -> WinRT_String: ...
    @winrt_commethod(17)
    def get_JobTitle(self) -> WinRT_String: ...
    @winrt_commethod(18)
    def get_Birthdate(self) -> WinRT_String: ...
    @winrt_commethod(19)
    def get_Anniversary(self) -> WinRT_String: ...
    @winrt_commethod(20)
    def get_Telephone(self) -> WinRT_String: ...
    @winrt_commethod(21)
    def get_MobileTelephone(self) -> WinRT_String: ...
    @winrt_commethod(22)
    def get_Url(self) -> WinRT_String: ...
    @winrt_commethod(23)
    def get_Notes(self) -> WinRT_String: ...
    @winrt_commethod(24)
    def get_WorkFax(self) -> WinRT_String: ...
    @winrt_commethod(25)
    def get_Children(self) -> WinRT_String: ...
    @winrt_commethod(26)
    def get_SignificantOther(self) -> WinRT_String: ...
    @winrt_commethod(27)
    def get_CompanyName(self) -> WinRT_String: ...
    @winrt_commethod(28)
    def get_CompanyTelephone(self) -> WinRT_String: ...
    @winrt_commethod(29)
    def get_HomeFax(self) -> WinRT_String: ...
    @winrt_commethod(30)
    def get_AlternateTelephone(self) -> WinRT_String: ...
    @winrt_commethod(31)
    def get_Manager(self) -> WinRT_String: ...
    @winrt_commethod(32)
    def get_Nickname(self) -> WinRT_String: ...
    @winrt_commethod(33)
    def get_OfficeLocation(self) -> WinRT_String: ...
    @winrt_commethod(34)
    def get_WorkEmail(self) -> WinRT_String: ...
    @winrt_commethod(35)
    def get_YomiGivenName(self) -> WinRT_String: ...
    @winrt_commethod(36)
    def get_YomiFamilyName(self) -> WinRT_String: ...
    @winrt_commethod(37)
    def get_YomiCompanyName(self) -> WinRT_String: ...
    @winrt_commethod(38)
    def get_OtherEmail(self) -> WinRT_String: ...
    @winrt_commethod(39)
    def get_AlternateMobileTelephone(self) -> WinRT_String: ...
    @winrt_commethod(40)
    def get_AlternateWorkTelephone(self) -> WinRT_String: ...
    AdditionalName = property(get_AdditionalName, None)
    Address = property(get_Address, None)
    AlternateMobileTelephone = property(get_AlternateMobileTelephone, None)
    AlternateTelephone = property(get_AlternateTelephone, None)
    AlternateWorkTelephone = property(get_AlternateWorkTelephone, None)
    Anniversary = property(get_Anniversary, None)
    Birthdate = property(get_Birthdate, None)
    Children = property(get_Children, None)
    CompanyName = property(get_CompanyName, None)
    CompanyTelephone = property(get_CompanyTelephone, None)
    DisplayName = property(get_DisplayName, None)
    Email = property(get_Email, None)
    FamilyName = property(get_FamilyName, None)
    GivenName = property(get_GivenName, None)
    HomeFax = property(get_HomeFax, None)
    HonorificPrefix = property(get_HonorificPrefix, None)
    HonorificSuffix = property(get_HonorificSuffix, None)
    JobTitle = property(get_JobTitle, None)
    Manager = property(get_Manager, None)
    MobileTelephone = property(get_MobileTelephone, None)
    Nickname = property(get_Nickname, None)
    Notes = property(get_Notes, None)
    OfficeLocation = property(get_OfficeLocation, None)
    OtherAddress = property(get_OtherAddress, None)
    OtherEmail = property(get_OtherEmail, None)
    SignificantOther = property(get_SignificantOther, None)
    Telephone = property(get_Telephone, None)
    Url = property(get_Url, None)
    WorkAddress = property(get_WorkAddress, None)
    WorkEmail = property(get_WorkEmail, None)
    WorkFax = property(get_WorkFax, None)
    WorkTelephone = property(get_WorkTelephone, None)
    YomiCompanyName = property(get_YomiCompanyName, None)
    YomiFamilyName = property(get_YomiFamilyName, None)
    YomiGivenName = property(get_YomiGivenName, None)
class IStoredContact(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.IStoredContact'
    _iid_ = Guid('{b070b7b1-263d-4e71-abe7-591d2466570e}')
    @winrt_commethod(6)
    def get_Store(self) -> win32more.Windows.Phone.PersonalInformation.ContactStore: ...
    @winrt_commethod(7)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_RemoteId(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_RemoteId(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def GetExtendedPropertiesAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]: ...
    @winrt_commethod(11)
    def SaveAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(12)
    def ReplaceExistingContactAsync(self, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    Id = property(get_Id, None)
    RemoteId = property(get_RemoteId, put_RemoteId)
    Store = property(get_Store, None)
class IStoredContactFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.IStoredContactFactory'
    _iid_ = Guid('{49ede921-c225-4fd9-89c5-cecc2c8a4b79}')
    @winrt_commethod(6)
    def CreateStoredContact(self, store: win32more.Windows.Phone.PersonalInformation.ContactStore) -> win32more.Windows.Phone.PersonalInformation.StoredContact: ...
    @winrt_commethod(7)
    def CreateStoredContactFromInformation(self, store: win32more.Windows.Phone.PersonalInformation.ContactStore, contact: win32more.Windows.Phone.PersonalInformation.ContactInformation) -> win32more.Windows.Phone.PersonalInformation.StoredContact: ...
class _KnownContactProperties_Meta_(ComPtr.__class__):
    pass
class KnownContactProperties(ComPtr, metaclass=_KnownContactProperties_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Phone.PersonalInformation.KnownContactProperties'
    @winrt_classmethod
    def get_DisplayName(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_FamilyName(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_GivenName(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_HonorificPrefix(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_HonorificSuffix(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_AdditionalName(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_Address(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_OtherAddress(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_Email(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_WorkAddress(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_WorkTelephone(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_JobTitle(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_Birthdate(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_Anniversary(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_Telephone(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_MobileTelephone(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_Url(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_Notes(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_WorkFax(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_Children(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_SignificantOther(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_CompanyName(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_CompanyTelephone(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_HomeFax(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_AlternateTelephone(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_Manager(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_Nickname(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_OfficeLocation(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_WorkEmail(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_YomiGivenName(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_YomiFamilyName(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_YomiCompanyName(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_OtherEmail(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_AlternateMobileTelephone(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    @winrt_classmethod
    def get_AlternateWorkTelephone(cls: win32more.Windows.Phone.PersonalInformation.IKnownContactPropertiesStatics) -> WinRT_String: ...
    _KnownContactProperties_Meta_.AdditionalName = property(get_AdditionalName, None)
    _KnownContactProperties_Meta_.Address = property(get_Address, None)
    _KnownContactProperties_Meta_.AlternateMobileTelephone = property(get_AlternateMobileTelephone, None)
    _KnownContactProperties_Meta_.AlternateTelephone = property(get_AlternateTelephone, None)
    _KnownContactProperties_Meta_.AlternateWorkTelephone = property(get_AlternateWorkTelephone, None)
    _KnownContactProperties_Meta_.Anniversary = property(get_Anniversary, None)
    _KnownContactProperties_Meta_.Birthdate = property(get_Birthdate, None)
    _KnownContactProperties_Meta_.Children = property(get_Children, None)
    _KnownContactProperties_Meta_.CompanyName = property(get_CompanyName, None)
    _KnownContactProperties_Meta_.CompanyTelephone = property(get_CompanyTelephone, None)
    _KnownContactProperties_Meta_.DisplayName = property(get_DisplayName, None)
    _KnownContactProperties_Meta_.Email = property(get_Email, None)
    _KnownContactProperties_Meta_.FamilyName = property(get_FamilyName, None)
    _KnownContactProperties_Meta_.GivenName = property(get_GivenName, None)
    _KnownContactProperties_Meta_.HomeFax = property(get_HomeFax, None)
    _KnownContactProperties_Meta_.HonorificPrefix = property(get_HonorificPrefix, None)
    _KnownContactProperties_Meta_.HonorificSuffix = property(get_HonorificSuffix, None)
    _KnownContactProperties_Meta_.JobTitle = property(get_JobTitle, None)
    _KnownContactProperties_Meta_.Manager = property(get_Manager, None)
    _KnownContactProperties_Meta_.MobileTelephone = property(get_MobileTelephone, None)
    _KnownContactProperties_Meta_.Nickname = property(get_Nickname, None)
    _KnownContactProperties_Meta_.Notes = property(get_Notes, None)
    _KnownContactProperties_Meta_.OfficeLocation = property(get_OfficeLocation, None)
    _KnownContactProperties_Meta_.OtherAddress = property(get_OtherAddress, None)
    _KnownContactProperties_Meta_.OtherEmail = property(get_OtherEmail, None)
    _KnownContactProperties_Meta_.SignificantOther = property(get_SignificantOther, None)
    _KnownContactProperties_Meta_.Telephone = property(get_Telephone, None)
    _KnownContactProperties_Meta_.Url = property(get_Url, None)
    _KnownContactProperties_Meta_.WorkAddress = property(get_WorkAddress, None)
    _KnownContactProperties_Meta_.WorkEmail = property(get_WorkEmail, None)
    _KnownContactProperties_Meta_.WorkFax = property(get_WorkFax, None)
    _KnownContactProperties_Meta_.WorkTelephone = property(get_WorkTelephone, None)
    _KnownContactProperties_Meta_.YomiCompanyName = property(get_YomiCompanyName, None)
    _KnownContactProperties_Meta_.YomiFamilyName = property(get_YomiFamilyName, None)
    _KnownContactProperties_Meta_.YomiGivenName = property(get_YomiGivenName, None)
class StoredContact(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Phone.PersonalInformation.IStoredContact
    _classid_ = 'Windows.Phone.PersonalInformation.StoredContact'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Phone.PersonalInformation.StoredContact.CreateStoredContact(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Phone.PersonalInformation.StoredContact.CreateStoredContactFromInformation(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateStoredContact(cls: win32more.Windows.Phone.PersonalInformation.IStoredContactFactory, store: win32more.Windows.Phone.PersonalInformation.ContactStore) -> win32more.Windows.Phone.PersonalInformation.StoredContact: ...
    @winrt_factorymethod
    def CreateStoredContactFromInformation(cls: win32more.Windows.Phone.PersonalInformation.IStoredContactFactory, store: win32more.Windows.Phone.PersonalInformation.ContactStore, contact: win32more.Windows.Phone.PersonalInformation.ContactInformation) -> win32more.Windows.Phone.PersonalInformation.StoredContact: ...
    @winrt_mixinmethod
    def get_Store(self: win32more.Windows.Phone.PersonalInformation.IStoredContact) -> win32more.Windows.Phone.PersonalInformation.ContactStore: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Phone.PersonalInformation.IStoredContact) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_RemoteId(self: win32more.Windows.Phone.PersonalInformation.IStoredContact) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_RemoteId(self: win32more.Windows.Phone.PersonalInformation.IStoredContact, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def GetExtendedPropertiesAsync(self: win32more.Windows.Phone.PersonalInformation.IStoredContact) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]: ...
    @winrt_mixinmethod
    def SaveAsync(self: win32more.Windows.Phone.PersonalInformation.IStoredContact) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReplaceExistingContactAsync(self: win32more.Windows.Phone.PersonalInformation.IStoredContact, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_FamilyName(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_FamilyName(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_GivenName(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_GivenName(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_HonorificPrefix(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_HonorificPrefix(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_HonorificSuffix(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_HonorificSuffix(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def GetDisplayPictureAsync(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_mixinmethod
    def SetDisplayPictureAsync(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, stream: win32more.Windows.Storage.Streams.IInputStream) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def get_DisplayPicture(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def GetPropertiesAsync(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]]: ...
    @winrt_mixinmethod
    def ToVcardAsync(self: win32more.Windows.Phone.PersonalInformation.IContactInformation) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_mixinmethod
    def ToVcardWithOptionsAsync(self: win32more.Windows.Phone.PersonalInformation.IContactInformation, format: win32more.Windows.Phone.PersonalInformation.VCardFormat) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_mixinmethod
    def get_DisplayPictureDate(self: win32more.Windows.Phone.PersonalInformation.IContactInformation2) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def put_DisplayPictureDate(self: win32more.Windows.Phone.PersonalInformation.IContactInformation2, returnValue: win32more.Windows.Foundation.DateTime) -> Void: ...
    DisplayName = property(get_DisplayName, put_DisplayName)
    DisplayPicture = property(get_DisplayPicture, None)
    DisplayPictureDate = property(get_DisplayPictureDate, put_DisplayPictureDate)
    FamilyName = property(get_FamilyName, put_FamilyName)
    GivenName = property(get_GivenName, put_GivenName)
    HonorificPrefix = property(get_HonorificPrefix, put_HonorificPrefix)
    HonorificSuffix = property(get_HonorificSuffix, put_HonorificSuffix)
    Id = property(get_Id, None)
    RemoteId = property(get_RemoteId, put_RemoteId)
    Store = property(get_Store, None)
class VCardFormat(Enum, Int32):
    Version2_1 = 0
    Version3 = 1


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Networking
import win32more.Windows.Networking.Connectivity
import win32more.Windows.Win32.System.WinRT
class DomainNameType(Enum, Int32):
    Suffix = 0
    FullyQualified = 1
class EndpointPair(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.IEndpointPair
    _classid_ = 'Windows.Networking.EndpointPair'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 4:
            super().__init__(move=win32more.Windows.Networking.EndpointPair.CreateEndpointPair(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateEndpointPair(cls: win32more.Windows.Networking.IEndpointPairFactory, localHostName: win32more.Windows.Networking.HostName, localServiceName: WinRT_String, remoteHostName: win32more.Windows.Networking.HostName, remoteServiceName: WinRT_String) -> win32more.Windows.Networking.EndpointPair: ...
    @winrt_mixinmethod
    def get_LocalHostName(self: win32more.Windows.Networking.IEndpointPair) -> win32more.Windows.Networking.HostName: ...
    @winrt_mixinmethod
    def put_LocalHostName(self: win32more.Windows.Networking.IEndpointPair, value: win32more.Windows.Networking.HostName) -> Void: ...
    @winrt_mixinmethod
    def get_LocalServiceName(self: win32more.Windows.Networking.IEndpointPair) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_LocalServiceName(self: win32more.Windows.Networking.IEndpointPair, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_RemoteHostName(self: win32more.Windows.Networking.IEndpointPair) -> win32more.Windows.Networking.HostName: ...
    @winrt_mixinmethod
    def put_RemoteHostName(self: win32more.Windows.Networking.IEndpointPair, value: win32more.Windows.Networking.HostName) -> Void: ...
    @winrt_mixinmethod
    def get_RemoteServiceName(self: win32more.Windows.Networking.IEndpointPair) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_RemoteServiceName(self: win32more.Windows.Networking.IEndpointPair, value: WinRT_String) -> Void: ...
    LocalHostName = property(get_LocalHostName, put_LocalHostName)
    LocalServiceName = property(get_LocalServiceName, put_LocalServiceName)
    RemoteHostName = property(get_RemoteHostName, put_RemoteHostName)
    RemoteServiceName = property(get_RemoteServiceName, put_RemoteServiceName)
class HostName(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Networking.IHostName
    _classid_ = 'Windows.Networking.HostName'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Networking.HostName.CreateHostName(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateHostName(cls: win32more.Windows.Networking.IHostNameFactory, hostName: WinRT_String) -> win32more.Windows.Networking.HostName: ...
    @winrt_mixinmethod
    def get_IPInformation(self: win32more.Windows.Networking.IHostName) -> win32more.Windows.Networking.Connectivity.IPInformation: ...
    @winrt_mixinmethod
    def get_RawName(self: win32more.Windows.Networking.IHostName) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Networking.IHostName) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_CanonicalName(self: win32more.Windows.Networking.IHostName) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Type(self: win32more.Windows.Networking.IHostName) -> win32more.Windows.Networking.HostNameType: ...
    @winrt_mixinmethod
    def IsEqual(self: win32more.Windows.Networking.IHostName, hostName: win32more.Windows.Networking.HostName) -> Boolean: ...
    @winrt_mixinmethod
    def ToString(self: win32more.Windows.Foundation.IStringable) -> WinRT_String: ...
    @winrt_classmethod
    def Compare(cls: win32more.Windows.Networking.IHostNameStatics, value1: WinRT_String, value2: WinRT_String) -> Int32: ...
    CanonicalName = property(get_CanonicalName, None)
    DisplayName = property(get_DisplayName, None)
    IPInformation = property(get_IPInformation, None)
    RawName = property(get_RawName, None)
    Type = property(get_Type, None)
class HostNameSortOptions(Enum, UInt32):
    None_ = 0
    OptimizeForLongConnections = 2
class HostNameType(Enum, Int32):
    DomainName = 0
    Ipv4 = 1
    Ipv6 = 2
    Bluetooth = 3
class IEndpointPair(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.IEndpointPair'
    _iid_ = Guid('{33a0aa36-f8fa-4b30-b856-76517c3bd06d}')
    @winrt_commethod(6)
    def get_LocalHostName(self) -> win32more.Windows.Networking.HostName: ...
    @winrt_commethod(7)
    def put_LocalHostName(self, value: win32more.Windows.Networking.HostName) -> Void: ...
    @winrt_commethod(8)
    def get_LocalServiceName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_LocalServiceName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_RemoteHostName(self) -> win32more.Windows.Networking.HostName: ...
    @winrt_commethod(11)
    def put_RemoteHostName(self, value: win32more.Windows.Networking.HostName) -> Void: ...
    @winrt_commethod(12)
    def get_RemoteServiceName(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_RemoteServiceName(self, value: WinRT_String) -> Void: ...
    LocalHostName = property(get_LocalHostName, put_LocalHostName)
    LocalServiceName = property(get_LocalServiceName, put_LocalServiceName)
    RemoteHostName = property(get_RemoteHostName, put_RemoteHostName)
    RemoteServiceName = property(get_RemoteServiceName, put_RemoteServiceName)
class IEndpointPairFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.IEndpointPairFactory'
    _iid_ = Guid('{b609d971-64e0-442b-aa6f-cc8c8f181f78}')
    @winrt_commethod(6)
    def CreateEndpointPair(self, localHostName: win32more.Windows.Networking.HostName, localServiceName: WinRT_String, remoteHostName: win32more.Windows.Networking.HostName, remoteServiceName: WinRT_String) -> win32more.Windows.Networking.EndpointPair: ...
class IHostName(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.IHostName'
    _iid_ = Guid('{bf8ecaad-ed96-49a7-9084-d416cae88dcb}')
    @winrt_commethod(6)
    def get_IPInformation(self) -> win32more.Windows.Networking.Connectivity.IPInformation: ...
    @winrt_commethod(7)
    def get_RawName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_CanonicalName(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_Type(self) -> win32more.Windows.Networking.HostNameType: ...
    @winrt_commethod(11)
    def IsEqual(self, hostName: win32more.Windows.Networking.HostName) -> Boolean: ...
    CanonicalName = property(get_CanonicalName, None)
    DisplayName = property(get_DisplayName, None)
    IPInformation = property(get_IPInformation, None)
    RawName = property(get_RawName, None)
    Type = property(get_Type, None)
class IHostNameFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.IHostNameFactory'
    _iid_ = Guid('{458c23ed-712f-4576-adf1-c20b2c643558}')
    @winrt_commethod(6)
    def CreateHostName(self, hostName: WinRT_String) -> win32more.Windows.Networking.HostName: ...
class IHostNameStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Networking.IHostNameStatics'
    _iid_ = Guid('{f68cd4bf-a388-4e8b-91ea-54dd6dd901c0}')
    @winrt_commethod(6)
    def Compare(self, value1: WinRT_String, value2: WinRT_String) -> Int32: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Globalization.Fonts
import win32more.Windows.UI.Text
import win32more.Windows.Win32.System.WinRT
class ILanguageFont(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.Fonts.ILanguageFont'
    _iid_ = Guid('{b12e5c3a-b76d-459b-beeb-901151cd77d1}')
    @winrt_commethod(6)
    def get_FontFamily(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_FontWeight(self) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_commethod(8)
    def get_FontStretch(self) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_commethod(9)
    def get_FontStyle(self) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_commethod(10)
    def get_ScaleFactor(self) -> Double: ...
    FontFamily = property(get_FontFamily, None)
    FontStretch = property(get_FontStretch, None)
    FontStyle = property(get_FontStyle, None)
    FontWeight = property(get_FontWeight, None)
    ScaleFactor = property(get_ScaleFactor, None)
class ILanguageFontGroup(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.Fonts.ILanguageFontGroup'
    _iid_ = Guid('{f33a7fc3-3a5c-4aea-b9ff-b39fb242f7f6}')
    @winrt_commethod(6)
    def get_UITextFont(self) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_commethod(7)
    def get_UIHeadingFont(self) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_commethod(8)
    def get_UITitleFont(self) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_commethod(9)
    def get_UICaptionFont(self) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_commethod(10)
    def get_UINotificationHeadingFont(self) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_commethod(11)
    def get_TraditionalDocumentFont(self) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_commethod(12)
    def get_ModernDocumentFont(self) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_commethod(13)
    def get_DocumentHeadingFont(self) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_commethod(14)
    def get_FixedWidthTextFont(self) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_commethod(15)
    def get_DocumentAlternate1Font(self) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_commethod(16)
    def get_DocumentAlternate2Font(self) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    DocumentAlternate1Font = property(get_DocumentAlternate1Font, None)
    DocumentAlternate2Font = property(get_DocumentAlternate2Font, None)
    DocumentHeadingFont = property(get_DocumentHeadingFont, None)
    FixedWidthTextFont = property(get_FixedWidthTextFont, None)
    ModernDocumentFont = property(get_ModernDocumentFont, None)
    TraditionalDocumentFont = property(get_TraditionalDocumentFont, None)
    UICaptionFont = property(get_UICaptionFont, None)
    UIHeadingFont = property(get_UIHeadingFont, None)
    UINotificationHeadingFont = property(get_UINotificationHeadingFont, None)
    UITextFont = property(get_UITextFont, None)
    UITitleFont = property(get_UITitleFont, None)
class ILanguageFontGroupFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.Fonts.ILanguageFontGroupFactory'
    _iid_ = Guid('{fcaeac67-4e77-49c7-b856-dde934fc735b}')
    @winrt_commethod(6)
    def CreateLanguageFontGroup(self, languageTag: WinRT_String) -> win32more.Windows.Globalization.Fonts.LanguageFontGroup: ...
class LanguageFont(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Globalization.Fonts.ILanguageFont
    _classid_ = 'Windows.Globalization.Fonts.LanguageFont'
    @winrt_mixinmethod
    def get_FontFamily(self: win32more.Windows.Globalization.Fonts.ILanguageFont) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FontWeight(self: win32more.Windows.Globalization.Fonts.ILanguageFont) -> win32more.Windows.UI.Text.FontWeight: ...
    @winrt_mixinmethod
    def get_FontStretch(self: win32more.Windows.Globalization.Fonts.ILanguageFont) -> win32more.Windows.UI.Text.FontStretch: ...
    @winrt_mixinmethod
    def get_FontStyle(self: win32more.Windows.Globalization.Fonts.ILanguageFont) -> win32more.Windows.UI.Text.FontStyle: ...
    @winrt_mixinmethod
    def get_ScaleFactor(self: win32more.Windows.Globalization.Fonts.ILanguageFont) -> Double: ...
    FontFamily = property(get_FontFamily, None)
    FontStretch = property(get_FontStretch, None)
    FontStyle = property(get_FontStyle, None)
    FontWeight = property(get_FontWeight, None)
    ScaleFactor = property(get_ScaleFactor, None)
class LanguageFontGroup(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Globalization.Fonts.ILanguageFontGroup
    _classid_ = 'Windows.Globalization.Fonts.LanguageFontGroup'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Globalization.Fonts.LanguageFontGroup.CreateLanguageFontGroup(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateLanguageFontGroup(cls: win32more.Windows.Globalization.Fonts.ILanguageFontGroupFactory, languageTag: WinRT_String) -> win32more.Windows.Globalization.Fonts.LanguageFontGroup: ...
    @winrt_mixinmethod
    def get_UITextFont(self: win32more.Windows.Globalization.Fonts.ILanguageFontGroup) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_mixinmethod
    def get_UIHeadingFont(self: win32more.Windows.Globalization.Fonts.ILanguageFontGroup) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_mixinmethod
    def get_UITitleFont(self: win32more.Windows.Globalization.Fonts.ILanguageFontGroup) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_mixinmethod
    def get_UICaptionFont(self: win32more.Windows.Globalization.Fonts.ILanguageFontGroup) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_mixinmethod
    def get_UINotificationHeadingFont(self: win32more.Windows.Globalization.Fonts.ILanguageFontGroup) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_mixinmethod
    def get_TraditionalDocumentFont(self: win32more.Windows.Globalization.Fonts.ILanguageFontGroup) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_mixinmethod
    def get_ModernDocumentFont(self: win32more.Windows.Globalization.Fonts.ILanguageFontGroup) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_mixinmethod
    def get_DocumentHeadingFont(self: win32more.Windows.Globalization.Fonts.ILanguageFontGroup) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_mixinmethod
    def get_FixedWidthTextFont(self: win32more.Windows.Globalization.Fonts.ILanguageFontGroup) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_mixinmethod
    def get_DocumentAlternate1Font(self: win32more.Windows.Globalization.Fonts.ILanguageFontGroup) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    @winrt_mixinmethod
    def get_DocumentAlternate2Font(self: win32more.Windows.Globalization.Fonts.ILanguageFontGroup) -> win32more.Windows.Globalization.Fonts.LanguageFont: ...
    DocumentAlternate1Font = property(get_DocumentAlternate1Font, None)
    DocumentAlternate2Font = property(get_DocumentAlternate2Font, None)
    DocumentHeadingFont = property(get_DocumentHeadingFont, None)
    FixedWidthTextFont = property(get_FixedWidthTextFont, None)
    ModernDocumentFont = property(get_ModernDocumentFont, None)
    TraditionalDocumentFont = property(get_TraditionalDocumentFont, None)
    UICaptionFont = property(get_UICaptionFont, None)
    UIHeadingFont = property(get_UIHeadingFont, None)
    UINotificationHeadingFont = property(get_UINotificationHeadingFont, None)
    UITextFont = property(get_UITextFont, None)
    UITitleFont = property(get_UITitleFont, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.System.Power
import win32more.Windows.Win32.System.WinRT
class _BackgroundEnergyManager_Meta_(ComPtr.__class__):
    pass
class BackgroundEnergyManager(ComPtr, metaclass=_BackgroundEnergyManager_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Power.BackgroundEnergyManager'
    @winrt_classmethod
    def get_LowUsageLevel(cls: win32more.Windows.System.Power.IBackgroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def get_NearMaxAcceptableUsageLevel(cls: win32more.Windows.System.Power.IBackgroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def get_MaxAcceptableUsageLevel(cls: win32more.Windows.System.Power.IBackgroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def get_ExcessiveUsageLevel(cls: win32more.Windows.System.Power.IBackgroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def get_NearTerminationUsageLevel(cls: win32more.Windows.System.Power.IBackgroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def get_TerminationUsageLevel(cls: win32more.Windows.System.Power.IBackgroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def get_RecentEnergyUsage(cls: win32more.Windows.System.Power.IBackgroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def get_RecentEnergyUsageLevel(cls: win32more.Windows.System.Power.IBackgroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def add_RecentEnergyUsageIncreased(cls: win32more.Windows.System.Power.IBackgroundEnergyManagerStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_RecentEnergyUsageIncreased(cls: win32more.Windows.System.Power.IBackgroundEnergyManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_RecentEnergyUsageReturnedToLow(cls: win32more.Windows.System.Power.IBackgroundEnergyManagerStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_RecentEnergyUsageReturnedToLow(cls: win32more.Windows.System.Power.IBackgroundEnergyManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    _BackgroundEnergyManager_Meta_.ExcessiveUsageLevel = property(get_ExcessiveUsageLevel, None)
    _BackgroundEnergyManager_Meta_.LowUsageLevel = property(get_LowUsageLevel, None)
    _BackgroundEnergyManager_Meta_.MaxAcceptableUsageLevel = property(get_MaxAcceptableUsageLevel, None)
    _BackgroundEnergyManager_Meta_.NearMaxAcceptableUsageLevel = property(get_NearMaxAcceptableUsageLevel, None)
    _BackgroundEnergyManager_Meta_.NearTerminationUsageLevel = property(get_NearTerminationUsageLevel, None)
    _BackgroundEnergyManager_Meta_.RecentEnergyUsage = property(get_RecentEnergyUsage, None)
    _BackgroundEnergyManager_Meta_.RecentEnergyUsageLevel = property(get_RecentEnergyUsageLevel, None)
    _BackgroundEnergyManager_Meta_.TerminationUsageLevel = property(get_TerminationUsageLevel, None)
class BatteryStatus(Enum, Int32):
    NotPresent = 0
    Discharging = 1
    Idle = 2
    Charging = 3
class EnergySaverStatus(Enum, Int32):
    Disabled = 0
    Off = 1
    On = 2
class _ForegroundEnergyManager_Meta_(ComPtr.__class__):
    pass
class ForegroundEnergyManager(ComPtr, metaclass=_ForegroundEnergyManager_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Power.ForegroundEnergyManager'
    @winrt_classmethod
    def get_LowUsageLevel(cls: win32more.Windows.System.Power.IForegroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def get_NearMaxAcceptableUsageLevel(cls: win32more.Windows.System.Power.IForegroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def get_MaxAcceptableUsageLevel(cls: win32more.Windows.System.Power.IForegroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def get_ExcessiveUsageLevel(cls: win32more.Windows.System.Power.IForegroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def get_RecentEnergyUsage(cls: win32more.Windows.System.Power.IForegroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def get_RecentEnergyUsageLevel(cls: win32more.Windows.System.Power.IForegroundEnergyManagerStatics) -> UInt32: ...
    @winrt_classmethod
    def add_RecentEnergyUsageIncreased(cls: win32more.Windows.System.Power.IForegroundEnergyManagerStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_RecentEnergyUsageIncreased(cls: win32more.Windows.System.Power.IForegroundEnergyManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_RecentEnergyUsageReturnedToLow(cls: win32more.Windows.System.Power.IForegroundEnergyManagerStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_RecentEnergyUsageReturnedToLow(cls: win32more.Windows.System.Power.IForegroundEnergyManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    _ForegroundEnergyManager_Meta_.ExcessiveUsageLevel = property(get_ExcessiveUsageLevel, None)
    _ForegroundEnergyManager_Meta_.LowUsageLevel = property(get_LowUsageLevel, None)
    _ForegroundEnergyManager_Meta_.MaxAcceptableUsageLevel = property(get_MaxAcceptableUsageLevel, None)
    _ForegroundEnergyManager_Meta_.NearMaxAcceptableUsageLevel = property(get_NearMaxAcceptableUsageLevel, None)
    _ForegroundEnergyManager_Meta_.RecentEnergyUsage = property(get_RecentEnergyUsage, None)
    _ForegroundEnergyManager_Meta_.RecentEnergyUsageLevel = property(get_RecentEnergyUsageLevel, None)
class IBackgroundEnergyManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Power.IBackgroundEnergyManagerStatics'
    _iid_ = Guid('{b3161d95-1180-4376-96e1-4095568147ce}')
    @winrt_commethod(6)
    def get_LowUsageLevel(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_NearMaxAcceptableUsageLevel(self) -> UInt32: ...
    @winrt_commethod(8)
    def get_MaxAcceptableUsageLevel(self) -> UInt32: ...
    @winrt_commethod(9)
    def get_ExcessiveUsageLevel(self) -> UInt32: ...
    @winrt_commethod(10)
    def get_NearTerminationUsageLevel(self) -> UInt32: ...
    @winrt_commethod(11)
    def get_TerminationUsageLevel(self) -> UInt32: ...
    @winrt_commethod(12)
    def get_RecentEnergyUsage(self) -> UInt32: ...
    @winrt_commethod(13)
    def get_RecentEnergyUsageLevel(self) -> UInt32: ...
    @winrt_commethod(14)
    def add_RecentEnergyUsageIncreased(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_RecentEnergyUsageIncreased(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def add_RecentEnergyUsageReturnedToLow(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_RecentEnergyUsageReturnedToLow(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ExcessiveUsageLevel = property(get_ExcessiveUsageLevel, None)
    LowUsageLevel = property(get_LowUsageLevel, None)
    MaxAcceptableUsageLevel = property(get_MaxAcceptableUsageLevel, None)
    NearMaxAcceptableUsageLevel = property(get_NearMaxAcceptableUsageLevel, None)
    NearTerminationUsageLevel = property(get_NearTerminationUsageLevel, None)
    RecentEnergyUsage = property(get_RecentEnergyUsage, None)
    RecentEnergyUsageLevel = property(get_RecentEnergyUsageLevel, None)
    TerminationUsageLevel = property(get_TerminationUsageLevel, None)
    RecentEnergyUsageIncreased = event()
    RecentEnergyUsageReturnedToLow = event()
class IForegroundEnergyManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Power.IForegroundEnergyManagerStatics'
    _iid_ = Guid('{9ff86872-e677-4814-9a20-5337ca732b98}')
    @winrt_commethod(6)
    def get_LowUsageLevel(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_NearMaxAcceptableUsageLevel(self) -> UInt32: ...
    @winrt_commethod(8)
    def get_MaxAcceptableUsageLevel(self) -> UInt32: ...
    @winrt_commethod(9)
    def get_ExcessiveUsageLevel(self) -> UInt32: ...
    @winrt_commethod(10)
    def get_RecentEnergyUsage(self) -> UInt32: ...
    @winrt_commethod(11)
    def get_RecentEnergyUsageLevel(self) -> UInt32: ...
    @winrt_commethod(12)
    def add_RecentEnergyUsageIncreased(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_RecentEnergyUsageIncreased(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_RecentEnergyUsageReturnedToLow(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_RecentEnergyUsageReturnedToLow(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ExcessiveUsageLevel = property(get_ExcessiveUsageLevel, None)
    LowUsageLevel = property(get_LowUsageLevel, None)
    MaxAcceptableUsageLevel = property(get_MaxAcceptableUsageLevel, None)
    NearMaxAcceptableUsageLevel = property(get_NearMaxAcceptableUsageLevel, None)
    RecentEnergyUsage = property(get_RecentEnergyUsage, None)
    RecentEnergyUsageLevel = property(get_RecentEnergyUsageLevel, None)
    RecentEnergyUsageIncreased = event()
    RecentEnergyUsageReturnedToLow = event()
class IPowerManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Power.IPowerManagerStatics'
    _iid_ = Guid('{1394825d-62ce-4364-98d5-aa28c7fbd15b}')
    @winrt_commethod(6)
    def get_EnergySaverStatus(self) -> win32more.Windows.System.Power.EnergySaverStatus: ...
    @winrt_commethod(7)
    def add_EnergySaverStatusChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_EnergySaverStatusChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def get_BatteryStatus(self) -> win32more.Windows.System.Power.BatteryStatus: ...
    @winrt_commethod(10)
    def add_BatteryStatusChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_BatteryStatusChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def get_PowerSupplyStatus(self) -> win32more.Windows.System.Power.PowerSupplyStatus: ...
    @winrt_commethod(13)
    def add_PowerSupplyStatusChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_PowerSupplyStatusChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(15)
    def get_RemainingChargePercent(self) -> Int32: ...
    @winrt_commethod(16)
    def add_RemainingChargePercentChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_RemainingChargePercentChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def get_RemainingDischargeTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(19)
    def add_RemainingDischargeTimeChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(20)
    def remove_RemainingDischargeTimeChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    BatteryStatus = property(get_BatteryStatus, None)
    EnergySaverStatus = property(get_EnergySaverStatus, None)
    PowerSupplyStatus = property(get_PowerSupplyStatus, None)
    RemainingChargePercent = property(get_RemainingChargePercent, None)
    RemainingDischargeTime = property(get_RemainingDischargeTime, None)
    EnergySaverStatusChanged = event()
    BatteryStatusChanged = event()
    PowerSupplyStatusChanged = event()
    RemainingChargePercentChanged = event()
    RemainingDischargeTimeChanged = event()
class _PowerManager_Meta_(ComPtr.__class__):
    pass
class PowerManager(ComPtr, metaclass=_PowerManager_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Power.PowerManager'
    @winrt_classmethod
    def get_EnergySaverStatus(cls: win32more.Windows.System.Power.IPowerManagerStatics) -> win32more.Windows.System.Power.EnergySaverStatus: ...
    @winrt_classmethod
    def add_EnergySaverStatusChanged(cls: win32more.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_EnergySaverStatusChanged(cls: win32more.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_BatteryStatus(cls: win32more.Windows.System.Power.IPowerManagerStatics) -> win32more.Windows.System.Power.BatteryStatus: ...
    @winrt_classmethod
    def add_BatteryStatusChanged(cls: win32more.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_BatteryStatusChanged(cls: win32more.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_PowerSupplyStatus(cls: win32more.Windows.System.Power.IPowerManagerStatics) -> win32more.Windows.System.Power.PowerSupplyStatus: ...
    @winrt_classmethod
    def add_PowerSupplyStatusChanged(cls: win32more.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_PowerSupplyStatusChanged(cls: win32more.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_RemainingChargePercent(cls: win32more.Windows.System.Power.IPowerManagerStatics) -> Int32: ...
    @winrt_classmethod
    def add_RemainingChargePercentChanged(cls: win32more.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_RemainingChargePercentChanged(cls: win32more.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_RemainingDischargeTime(cls: win32more.Windows.System.Power.IPowerManagerStatics) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_classmethod
    def add_RemainingDischargeTimeChanged(cls: win32more.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_RemainingDischargeTimeChanged(cls: win32more.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    _PowerManager_Meta_.BatteryStatus = property(get_BatteryStatus, None)
    _PowerManager_Meta_.EnergySaverStatus = property(get_EnergySaverStatus, None)
    _PowerManager_Meta_.PowerSupplyStatus = property(get_PowerSupplyStatus, None)
    _PowerManager_Meta_.RemainingChargePercent = property(get_RemainingChargePercent, None)
    _PowerManager_Meta_.RemainingDischargeTime = property(get_RemainingDischargeTime, None)
class PowerSupplyStatus(Enum, Int32):
    NotPresent = 0
    Inadequate = 1
    Adequate = 2


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Com.ChannelCredentials
import win32more.Windows.Win32.System.Variant
class IChannelCredentials(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{181b448c-c17c-4b17-ac6d-06699b93198f}')
    @commethod(7)
    def SetWindowsCredential(self, domain: win32more.Windows.Win32.Foundation.BSTR, username: win32more.Windows.Win32.Foundation.BSTR, password: win32more.Windows.Win32.Foundation.BSTR, impersonationLevel: Int32, allowNtlm: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetUserNameCredential(self, username: win32more.Windows.Win32.Foundation.BSTR, password: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def SetClientCertificateFromStore(self, storeLocation: win32more.Windows.Win32.Foundation.BSTR, storeName: win32more.Windows.Win32.Foundation.BSTR, findYype: win32more.Windows.Win32.Foundation.BSTR, findValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetClientCertificateFromStoreByName(self, subjectName: win32more.Windows.Win32.Foundation.BSTR, storeLocation: win32more.Windows.Win32.Foundation.BSTR, storeName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetClientCertificateFromFile(self, filename: win32more.Windows.Win32.Foundation.BSTR, password: win32more.Windows.Win32.Foundation.BSTR, keystorageFlags: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetDefaultServiceCertificateFromStore(self, storeLocation: win32more.Windows.Win32.Foundation.BSTR, storeName: win32more.Windows.Win32.Foundation.BSTR, findType: win32more.Windows.Win32.Foundation.BSTR, findValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetDefaultServiceCertificateFromStoreByName(self, subjectName: win32more.Windows.Win32.Foundation.BSTR, storeLocation: win32more.Windows.Win32.Foundation.BSTR, storeName: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def SetDefaultServiceCertificateFromFile(self, filename: win32more.Windows.Win32.Foundation.BSTR, password: win32more.Windows.Win32.Foundation.BSTR, keystorageFlags: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def SetServiceCertificateAuthentication(self, storeLocation: win32more.Windows.Win32.Foundation.BSTR, revocationMode: win32more.Windows.Win32.Foundation.BSTR, certificateValidationMode: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetIssuedToken(self, localIssuerAddres: win32more.Windows.Win32.Foundation.BSTR, localIssuerBindingType: win32more.Windows.Win32.Foundation.BSTR, localIssuerBinding: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)
